package com.load;

import org.eclipse.paho.client.mqttv3.*;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;

/**
 * 订阅 MQTT 主题
 */
public class SubscribeSample {

    /**
     * 主程序入口。
     * 创建一个MQTT客户端，并连接到指定的代理服务器，订阅特定的主题，并处理接收到的消息。
     *
     */
   public static void main(String[] args) {
       /**
        * 代理地址
        */
       String broker = "tcp://47.92.127.83:1883";
       /**
        * 主题
        */
       String topic = "mqtt/test";
       String username = "emqx";
       String password = "public";
       /**
        * 客户端ID(随机)
        */
       String clientid = "protocol-parsing";
       int qos = 0;

       try {
           // 创建MqttClient实例
           MqttClient client = new MqttClient(broker, clientid, new MemoryPersistence());

           // 设置连接选项
           MqttConnectOptions options = new MqttConnectOptions();
           options.setUserName(username);
           options.setPassword(password.toCharArray());
           options.setConnectionTimeout(60);
//           堵塞60S
           options.setKeepAliveInterval(60);
           // 设置MQTT消息回调处理
           client.setCallback(new MqttCallback() {

               /**
                * 连接丢失时的处理逻辑。
                *
                * @param cause 引发连接丢失的异常对象
                */
               public void connectionLost(Throwable cause) {
                   System.out.println("connectionLost: " + cause.getMessage());
              }

               /**
                * 当接收到消息时的处理逻辑。
                *
                * @param topic 接收到消息的主题
                * @param message 接收到的消息对象
                */
               public void messageArrived(String topic, MqttMessage message) {
                   System.out.println("topic: " + topic);
                   System.out.println("Qos: " + message.getQos());
                   System.out.println("message content: " + new String(message.getPayload()));

              }
               /**
                * 消息成功发送完成的处理逻辑。
                *
                * @param token 表示消息发送过程的令牌
                */
               public void deliveryComplete(IMqttDeliveryToken token) {
                   System.out.println("deliveryComplete---------" + token.isComplete());
              }

          });
           // 连接到MQTT代理
           client.connect(options);
           // 订阅主题
           client.subscribe(topic, qos);
      } catch (Exception e) {
           e.printStackTrace();
      }
  }
}
