package com.load.mqtt;

import lombok.AllArgsConstructor;
import org.eclipse.paho.client.mqttv3.MqttClient;
import org.eclipse.paho.client.mqttv3.MqttConnectOptions;
import org.eclipse.paho.client.mqttv3.MqttException;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;
import org.springframework.stereotype.Service;

/**
  *  Mqtt工厂
  * @author YunFei.Du
  * @date  22:38 2024/5/30
 */
@Service
@AllArgsConstructor
public class MqttFactory {

    private final MessageCallbackService messageCallbackService;
    // 连接参数

    /**
     * 创建Mqtt 客户端
     * @param mqttProperties
     * @return
     */
    public  MqttClient  createClient(MqttProperties mqttProperties){
        MqttClient mqttClient =null;
        try {
             mqttClient=new MqttClient ( mqttProperties.getBroker() , mqttProperties.getClientId() , new MemoryPersistence() );

            MqttConnectOptions options = new MqttConnectOptions ( );

            //都不为空
            if (mqttProperties.isLogin()){
                options.setUserName ( mqttProperties.getUsername() );
                options.setPassword ( mqttProperties.getPassword().toCharArray() );
            }
            options.setConnectionTimeout(60);
            options.setKeepAliveInterval(60);

            mqttClient.connect ( options );
            //监听
            mqttClient.setCallback ( messageCallbackService );
            mqttClient.subscribe ( mqttProperties.getTopic(),0 );
        } catch (MqttException e) {
            throw new RuntimeException ( e );
        }


//        try {
//
//        } catch (MqttException e) {
//            throw new RuntimeException ( e );
//        }
        return mqttClient;
    }
}
